==> eam-wshub-proxyclient-11.4-14-sources.jar: org/openapplications/oagis_segments/ObjectFactory.java <==

package org.openapplications.oagis_segments;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.openapplications.oagis_segments package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.openapplications.oagis_segments
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link DATETIME }
     * 
     */
    public DATETIME createDATETIME() {
        return new DATETIME();
    }

    /**
     * Create an instance of {@link QUANTITY }
     * 
     */
    public QUANTITY createQUANTITY() {
        return new QUANTITY();
    }

    /**
     * Create an instance of {@link AMOUNT }
     * 
     */
    public AMOUNT createAMOUNT() {
        return new AMOUNT();
    }

    /**
     * Create an instance of {@link TIME }
     * 
     */
    public TIME createTIME() {
        return new TIME();
    }

    /**
     * Create an instance of {@link OPERAMT }
     * 
     */
    public OPERAMT createOPERAMT() {
        return new OPERAMT();
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: org/openapplications/oagis_segments/ObjectFactory.java <==

package org.openapplications.oagis_segments;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.openapplications.oagis_segments package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.openapplications.oagis_segments
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link DATETIME }
     * 
     * @return
     *     the new instance of {@link DATETIME }
     */
    public DATETIME createDATETIME() {
        return new DATETIME();
    }

    /**
     * Create an instance of {@link QUANTITY }
     * 
     * @return
     *     the new instance of {@link QUANTITY }
     */
    public QUANTITY createQUANTITY() {
        return new QUANTITY();
    }

    /**
     * Create an instance of {@link AMOUNT }
     * 
     * @return
     *     the new instance of {@link AMOUNT }
     */
    public AMOUNT createAMOUNT() {
        return new AMOUNT();
    }

    /**
     * Create an instance of {@link TIME }
     * 
     * @return
     *     the new instance of {@link TIME }
     */
    public TIME createTIME() {
        return new TIME();
    }

    /**
     * Create an instance of {@link OPERAMT }
     * 
     * @return
     *     the new instance of {@link OPERAMT }
     */
    public OPERAMT createOPERAMT() {
        return new OPERAMT();
    }

}
